==> Blind-src-V2.43.zip: Blind-2.43/cmds/a.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.43/cmds/RCS/a.c,v 2.43 1995/03/20 01:43:09 zeus Exp zeus $";

/*
 *
 * $Log: a.c,v $
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * *** empty log message ***
 *
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"
#include "../protos/enterturn-g.h"

extern int pos;
extern char tbuf[];
extern player *players;
extern char err_tmp[];

void
a_cmd (char *buf, player * P)
{
  player *P2;
  alliance *a;
  defensive *d;

  hstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();
  P2 = ninputplayer ();
  if (P2)
  {				/* Valid command */
    if (P2 == P)		/* do this with everyone */
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a = a->next)
	    if (a->ally == P2)
	      break;
	  for (d = P->defend; d; d = d->next)
	    if (d->defend == P2)
	      removelist (&P->defend, d);
	  if (!a)
	  {
	    a = alloc (sizeof (alliance));
	    a->ally = P2;
	    addlist (&P->allies, a);
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else /* only with player specified */
    {
      for (a = P->allies; a; a = a->next)
	if (a->ally == P2)
	  break;
      for (d = P->defend; d; d = d->next)
	if (d->defend == P2)
	  removelist (&P->defend, d);
      if (!a)
      {
	a = alloc (sizeof (alliance));
	a->ally = P2;
	addlist (&P->allies, a);
      }
    }
  }
  else /* Oops... */
  {
    error (err_tmp);
    return;
  }
  extra_token ();
}

==> Blind-src-V2.45.0.2.zip: Blind-2.45/cmds/a.c <==
static char *rcsid = "$Header: /silver/homes/zeus/Blind-2.44/cmds/RCS/a.c,v 2.44 1995/12/31 19:45:18 zeus Exp zeus $";

/*
 *
 * $Log: a.c,v $
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * *** empty log message ***
 *
 * Revision 2.43  1995/03/20  01:43:09  zeus
 *
 */

#define NOTIMEB
 
#include "../protos/common.h"
#include "../protos/prototypes.h"
#include "../protos/cmds.h"
#include "../protos/cmds-g.h"
#include "../protos/enterturn-g.h"

extern int pos;
extern char tbuf[];
extern player *players;
extern char err_tmp[];

void a_cmd_rcsid (void);
void
a_cmd_rcsid (void)
{
  printf ("%s\n",rcsid);
}

void
a_cmd (char *buf, player * P)
{
  player *P2;
  alliance *a;
  defensive *d,*d2;

  hcstrcpy (tbuf, buf);
  pos = 0;
  (void) next_token ();
  P2 = ninputplayer ();
  if (P2)
  {				/* Valid command */
    if (P2 == P)		/* do this with everyone */
    {
      for (P2 = players; P2; P2 = P2->next)
	if (P2 != P)
	{
	  for (a = P->allies; a; a = a->next)
	    if (a->ally == P2)
	      break;
	  for (d = P->defend; d; d=d2)
          {
            d2 = d->next;
	    if (d->defend == P2)
	      removelist (&P->defend, d);
          }
	  if (!a)
	  {
	    a = alloc (sizeof (alliance));
	    a->ally = P2;
	    addlist (&P->allies, a);
	  }
	}			/* end of inner "if not self" test */
    }				/* end of outer "if not self" test */
    else /* only with player specified */
    {
      for (a = P->allies; a; a = a->next)
	if (a->ally == P2)
	  break;
      for (d = P->defend; d; d=d2)
      {
        d2 = d->next;
	if (d->defend == P2)
	  removelist (&P->defend, d);
      }
      if (!a)
      {
	a = alloc (sizeof (alliance));
	a->ally = P2;
	addlist (&P->allies, a);
      }
    }
  }
  else /* Oops... */
  {
    error (err_tmp);
    return;
  }
  extra_token ();
}
